==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebColumnComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnComponentEventArgsDescription } from "./WebColumnComponentEventArgsDescription";
/**
 * @hidden
 */
var WebColumnComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnComponentEventArgsDescriptionMetadata, _super);
    function WebColumnComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnComponentEventArgsDescriptionMetadata.a == null) {
            WebColumnComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnComponentEventArgsDescriptionMetadata.c(WebColumnComponentEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebColumnComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnComponentEventArgsDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnComponentEventArgs");
        a.item("Detail", "ExportedType:WebColumn");
    };
    WebColumnComponentEventArgsDescriptionMetadata.d = function (a) {
        WebColumnComponentEventArgsDescriptionMetadata.b(a);
        a.aa("WebColumnComponentEventArgs", function () { return new WebColumnComponentEventArgsDescription(); });
        a.z("WebColumnComponentEventArgs", WebColumnComponentEventArgsDescriptionMetadata.a);
    };
    WebColumnComponentEventArgsDescriptionMetadata.$t = markType(WebColumnComponentEventArgsDescriptionMetadata, 'WebColumnComponentEventArgsDescriptionMetadata');
    WebColumnComponentEventArgsDescriptionMetadata.a = null;
    return WebColumnComponentEventArgsDescriptionMetadata;
}(Base));
export { WebColumnComponentEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebColumnComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnComponentEventArgsDescription } from "./WebColumnComponentEventArgsDescription";
/**
 * @hidden
 */
var WebColumnComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnComponentEventArgsDescriptionMetadata, _super);
    function WebColumnComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnComponentEventArgsDescriptionMetadata.a == null) {
            WebColumnComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnComponentEventArgsDescriptionMetadata.c(WebColumnComponentEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnComponentEventArgsDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnComponentEventArgs");
        a.item("Detail", "ExportedType:WebColumn");
    };
    WebColumnComponentEventArgsDescriptionMetadata.d = function (a) {
        WebColumnComponentEventArgsDescriptionMetadata.b(a);
        a.ac("WebColumnComponentEventArgs", function () { return new WebColumnComponentEventArgsDescription(); });
        a.ab("WebColumnComponentEventArgs", WebColumnComponentEventArgsDescriptionMetadata.a);
    };
    WebColumnComponentEventArgsDescriptionMetadata.$t = markType(WebColumnComponentEventArgsDescriptionMetadata, 'WebColumnComponentEventArgsDescriptionMetadata');
    WebColumnComponentEventArgsDescriptionMetadata.a = null;
    return WebColumnComponentEventArgsDescriptionMetadata;
}(Base));
export { WebColumnComponentEventArgsDescriptionMetadata };
